@@ -26,6 +26,7 @@ import Data.List
 import qualified Data.Colour.Chan as Chan
 import Data.Colour.Chan (Chan(Chan))
 import Data.Monoid
+import Data.Semigroup
 
 data Red = Red
 data Green = Green
@@ -53,6 +54,9 @@ colourConvert (RGB r g b) =
 black :: (Num a) => Colour a
 black = RGB Chan.empty Chan.empty Chan.empty
 
+instance (Num a) => Semigroup (Colour a) where
+  (<>) = mappend
+
 instance (Num a) => Monoid (Colour a) where
   mempty = black
   (RGB r1 g1 b1) `mappend` (RGB r2 g2 b2) =
@@ -168,6 +172,9 @@ instance ColourOps AlphaColour where
  darken s (RGBA c a) = RGBA (darken s c) a
 
 -- | 'AlphaColour' forms a monoid with 'over' and 'transparent'.
+instance (Num a) => Semigroup (AlphaColour a) where
+  (<>) = mappend
+
 instance (Num a) => Monoid (AlphaColour a) where
   mempty = transparent
   mappend = over
