@@ -334,7 +334,7 @@ readColourName "whitesmoke" = return whitesmoke
 readColourName "yellow" = return yellow
 readColourName "yellowgreen" = return yellowgreen
 readColourName x = fail $ 
-  "Data.Colour.Names.readColourNames: Unknown colour name "++show x
+  "Data.Colour.Names.readColourName: Unknown colour name "++show x
 
 aliceblue :: (Ord a, Floating a) => Colour a
 aliceblue = sRGB24 240 248 255
@@ -774,4 +774,4 @@ yellow :: (Ord a, Floating a) => Colour a
 yellow = sRGB24 255 255 0
 
 yellowgreen :: (Ord a, Floating a) => Colour a
-yellowgreen = sRGB24 154 205 50
\ No newline at end of file
+yellowgreen = sRGB24 154 205 50
